@@ -7,6 +7,30 @@
       ASPECT_RATIO_TOLERANCE = .1, // 10% tolerance.
       breakpoints = [{{ BETTY_WIDTHS|join:","}}];
 
+  // Credit to https://remysharp.com/2010/07/21/throttling-function-calls
+  function throttle(fn, threshhold, scope) {
+    threshhold || (threshhold = 250);
+    var last,
+        deferTimer;
+    return function () {
+      var context = scope || this;
+
+      var now = +new Date,
+          args = arguments;
+      if (last && now < last + threshhold) {
+        // hold on to it
+        clearTimeout(deferTimer);
+        deferTimer = setTimeout(function () {
+          last = now;
+          fn.apply(context, args);
+        }, threshhold);
+      } else {
+        last = now;
+        fn.apply(context, args);
+      }
+    };
+  }
+
   w.picturefill = function(elements, forceRerender) {
 
     // get elements to picturefill
@@ -30,9 +54,10 @@
         continue;
       }
 
-      // check if image is in viewport for lazy loading
+      // check if image is in viewport for lazy loading, and
+      // preload images if they're within 100px of being shown.
       var innerHeight = w.innerHeight || w.document.documentElement.clientHeight,
-          visible = el.getBoundingClientRect().top <= innerHeight;
+          visible = el.getBoundingClientRect().top <= (innerHeight + 250);
 
       // this is a div to picturefill, start working on it if it hasn't been rendered yet
       if (el.getAttribute("data-image-id") !== null
@@ -162,21 +187,21 @@
   // Run on resize and domready (w.load as a fallback)
   if (!w.IMAGE_LISTENERS_DISABLED) {
 
-    var pictureFillTimeout;
-    addEventListener(w, "resize", function () {
-      clearTimeout(pictureFillTimeout);
-      pictureFillTimeout = setTimeout(function () {
-        w.picturefill(null, true);
-      }, 100);
-    });
-
+    addEventListener(w, "load", w.picturefill);
     addEventListener(w, "DOMContentLoaded", function () {
       w.picturefill();
       removeEventListener(w, "load");
     });
 
-    addEventListener(w, "load", w.picturefill);
-    addEventListener(w, "scroll", w.picturefill);
+    var resizeTimeout;
+    addEventListener(w, "resize", function () {
+      clearTimeout(resizeTimeout);
+      resizeTimeout = setTimeout(function () {
+        w.picturefill(null, true);
+      }, 100);
+    });
+
+    addEventListener(w, "scroll", throttle(w.picturefill, 100));
 
   }
 
